@@ -1,8 +1,4 @@
 {-# LANGUAGE CPP #-}
-#if __GLASGOW_HASKELL__ >= 710
-{-# LANGUAGE PatternSynonyms #-}
-{-# LANGUAGE ViewPatterns    #-}
-#endif
 module Data.Time.Calendar.Julian.Compat (
     Year, MonthOfYear, DayOfMonth, DayOfYear,
 
@@ -14,9 +10,7 @@ module Data.Time.Calendar.Julian.Compat (
     isJulianLeapYear,
 
     toJulian,fromJulian,
-#if __GLASGOW_HASKELL__ >= 710
     pattern JulianYearMonthDay,
-#endif
     fromJulianValid,showJulian,julianMonthLength,
 
     -- calendrical arithmetic
@@ -29,7 +23,12 @@ module Data.Time.Calendar.Julian.Compat (
 
 import Data.Time.Orphans ()
 
+#if MIN_VERSION_time(1,9,0) && !MIN_VERSION_time(1,14,0)
+import Data.Time.Calendar.Julian hiding (diffJulianDurationRollOver)
+#else
 import Data.Time.Calendar.Julian
+#endif
+
 import Data.Time.Calendar.Compat
 
 #if !MIN_VERSION_time(1,11,0)
@@ -61,34 +60,42 @@ diffJulianDurationClip day2 day1 = let
     dayAllowed = addJulianDurationClip (CalendarDiffDays ymAllowed 0) day1
     in CalendarDiffDays ymAllowed $ diffDays day2 dayAllowed
 
--- | Calendrical difference, with as many whole months as possible.
--- Same as 'diffJulianDurationClip' for positive durations.
-diffJulianDurationRollOver :: Day -> Day -> CalendarDiffDays
-diffJulianDurationRollOver day2 day1 = let
-    (y1,m1,d1) = toJulian day1
-    (y2,m2,d2) = toJulian day2
-    ym1 = y1 * 12 + toInteger m1
-    ym2 = y2 * 12 + toInteger m2
-    ymdiff = ym2 - ym1
-    ymAllowed =
-        if day2 >= day1 then
-        if d2 >= d1 then ymdiff else ymdiff - 1
-        else if d2 <= d1 then ymdiff else ymdiff + 1
-    dayAllowed = addJulianDurationRollOver (CalendarDiffDays ymAllowed 0) day1
-    in CalendarDiffDays ymAllowed $ diffDays day2 dayAllowed
+#endif
 
+#if !MIN_VERSION_time(1,14,0)
+
+diffJulianDurationRollOver :: Day -> Day -> CalendarDiffDays
+diffJulianDurationRollOver day2 day1 =
+    let
+        (y1, m1, _) = toJulian day1
+        (y2, m2, _) = toJulian day2
+        ym1 = y1 * 12 + toInteger m1
+        ym2 = y2 * 12 + toInteger m2
+        ymdiff = ym2 - ym1
+        findpos mdiff =
+            let
+                dayAllowed = addJulianDurationRollOver (CalendarDiffDays mdiff 0) day1
+                dd = diffDays day2 dayAllowed
+            in
+                if dd >= 0 then CalendarDiffDays mdiff dd else findpos (pred mdiff)
+        findneg mdiff =
+            let
+                dayAllowed = addJulianDurationRollOver (CalendarDiffDays mdiff 0) day1
+                dd = diffDays day2 dayAllowed
+            in
+                if dd <= 0 then CalendarDiffDays mdiff dd else findpos (succ mdiff)
+    in
+        if day2 >= day1
+            then findpos ymdiff
+            else findneg ymdiff
 #endif
 
 #if !MIN_VERSION_time(1,11,0)
-#if __GLASGOW_HASKELL__ >= 710
 -- | Bidirectional abstract constructor for the proleptic Julian calendar.
 -- Invalid values will be clipped to the correct range, month first, then day.
 pattern JulianYearMonthDay :: Year -> MonthOfYear -> DayOfMonth -> Day
 pattern JulianYearMonthDay y m d <- (toJulian -> (y,m,d)) where
     JulianYearMonthDay y m d = fromJulian y m d
 
-#if __GLASGOW_HASKELL__ >= 802
 {-# COMPLETE JulianYearMonthDay #-}
 #endif
-#endif
-#endif
