@@ -1,12 +1,18 @@
 {-# LANGUAGE CPP #-}
-#if __GLASGOW_HASKELL__ >= 710
-{-# LANGUAGE PatternSynonyms #-}
-#endif
 module Data.Time.Calendar.MonthDay.Compat (
     MonthOfYear, DayOfMonth, DayOfYear,
-#if __GLASGOW_HASKELL__ >= 710
-    -- patterns
-#endif
+    pattern January,
+    pattern February,
+    pattern March,
+    pattern April,
+    pattern May,
+    pattern June,
+    pattern July,
+    pattern August,
+    pattern September,
+    pattern October,
+    pattern November,
+    pattern December,
     monthAndDayToDayOfYear,
     monthAndDayToDayOfYearValid,
     dayOfYearToMonthAndDay,
@@ -21,9 +27,7 @@ import Data.Time.Calendar.MonthDay
 import Data.Time.Calendar.Types
 #endif
 
-{-
 #if !MIN_VERSION_time(1,12,0)
-#if __GLASGOW_HASKELL__ >= 710
 pattern January :: MonthOfYear
 pattern January = 1
 
@@ -61,9 +65,5 @@ pattern November = 11
 pattern December :: MonthOfYear
 pattern December = 12
 
-#if __GLASGOW_HASKELL__ >= 802
 {-# COMPLETE January, February, March, April, May, June, July, August, September, October, November, December #-}
 #endif
-#endif
-#endif
--}
