@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE TemplateHaskellQuotes #-}
 module Data.Time.Clock.Compat (
     -- * Universal Time
     -- | Time as measured by the Earth.
@@ -22,7 +23,7 @@ module Data.Time.Clock.Compat (
     -- * UTC differences
     addUTCTime,
     diffUTCTime,
-  
+
     -- * Current time
     getCurrentTime,
     getTime_resolution,
@@ -38,6 +39,7 @@ import Data.Time.Calendar.Types
 
 import Data.Time.Clock
 import Data.Fixed (Pico)
+import Debug.Trace
 
 #if !MIN_VERSION_time(1,9,1)
 
@@ -50,21 +52,3 @@ nominalDiffTimeToSeconds :: NominalDiffTime -> Pico
 nominalDiffTimeToSeconds = realToFrac
 
 #endif
-
-#if !MIN_VERSION_time(1,8,0)
--- | One day in 'NominalDiffTime'.
-nominalDay :: NominalDiffTime
-nominalDay = 86400
-#endif
-
-#if !MIN_VERSION_time(1,8,0)
--- | The resolution of 'getSystemTime', 'getCurrentTime', 'getPOSIXTime'
-getTime_resolution :: DiffTime
-getTime_resolution = 1E-6 -- microsecond
-#endif
-
-#if !MIN_VERSION_time(1,6,0)
--- | Get the number of picoseconds in a 'DiffTime'.
-diffTimeToPicoseconds :: DiffTime -> Integer
-diffTimeToPicoseconds = truncate . (1000000000000 *)
-#endif
